@@ -6,8 +6,6 @@ novel_downloader.cli
 This module exposes the CLI entry point.
 """
 
-__all__ = [
-    "cli_main",
-]
+__all__ = ["cli_main"]
 
 from .main import cli_main
