@@ -4,17 +4,20 @@ novel_downloader.config
 -----------------------
 
 Unified interface for loading and adapting configuration files.
-
-This module provides:
-- load_config: loads YAML config from file path with fallback support
-- ConfigAdapter: maps raw config + site name to structured config models
 """
 
 __all__ = [
+    "get_config_value",
     "load_config",
+    "save_config",
     "save_config_file",
     "ConfigAdapter",
 ]
 
 from .adapter import ConfigAdapter
-from .loader import load_config, save_config_file
+from .file_io import (
+    get_config_value,
+    load_config,
+    save_config,
+    save_config_file,
+)
