@@ -3,9 +3,30 @@
 novel_downloader.models
 -----------------------
 
+Data models and configuration classes.
 """
 
-from .chapter import ChapterDict
+__all__ = [
+    "BookConfig",
+    "DownloaderConfig",
+    "ParserConfig",
+    "FetcherConfig",
+    "ExporterConfig",
+    "TextCleanerConfig",
+    "BookInfoDict",
+    "ChapterDict",
+    "ChapterInfoDict",
+    "VolumeInfoDict",
+    "LoginField",
+    "SearchResult",
+]
+
+from .book import (
+    BookInfoDict,
+    ChapterDict,
+    ChapterInfoDict,
+    VolumeInfoDict,
+)
 from .config import (
     BookConfig,
     DownloaderConfig,
@@ -16,25 +37,3 @@ from .config import (
 )
 from .login import LoginField
 from .search import SearchResult
-from .types import (
-    BrowserType,
-    LogLevel,
-    ModeType,
-    SplitMode,
-)
-
-__all__ = [
-    "BookConfig",
-    "DownloaderConfig",
-    "ParserConfig",
-    "FetcherConfig",
-    "ExporterConfig",
-    "TextCleanerConfig",
-    "ChapterDict",
-    "LoginField",
-    "SearchResult",
-    "BrowserType",
-    "ModeType",
-    "SplitMode",
-    "LogLevel",
-]
